@@ -1,12 +1,11 @@
 package SMS::Send::DeviceGsm;
+$SMS::Send::DeviceGsm::VERSION = '1.08';
+#ABSTRACT: An SMS::Send driver for Device::Gsm.
 
 use strict;
 use warnings;
 use base qw(SMS::Send::Driver);
 use Device::Gsm;
-use vars qw($VERSION);
-
-$VERSION = '1.06';
 
 sub new {
   my $package = shift;
@@ -33,13 +32,22 @@ sub write {
   1;
 }
 
-1;
+'Call me!';
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 SMS::Send::DeviceGsm - An SMS::Send driver for Device::Gsm.
 
+=head1 VERSION
+
+version 1.08
+
 =head1 SYNOPSIS
 
   my $sender = SMS::Send->new('DeviceGsm',
@@ -77,6 +85,8 @@ this module.
 
 Using this driver will cost you money. B<YOU HAVE BEEN WARNED>
 
+=for Pod::Coverage write
+
 =head1 METHODS
 
 =head2 C<new>
@@ -126,29 +136,21 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SMS-Send-DeviceGsm>
 
 For other issues, contact the author.
 
-=head1 AUTHOR
-
-Chris Williams E<lt>chris@bingosnet.co.uk<gt>
-
-=head1 LICENSE 
-
-Copyright E<copy> Chris Williams
-
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
-
-Additionally, you are again reminded that this software comes with
-no warranty of any kind, including but not limited to the implied
-warranty of merchantability.
-
-ANY use may result in charges on your phone bill, and you should use this
-software with care. The author takes no responsibility for any such
-charges accrued.
-
 =head1 SEE ALSO
 
 L<SMS::Send>
 
 L<Device::Gsm>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
